pub fn new_batch_queue(
capacity: usize,
) -> (BatchQueueSender, BatchQueueReceiver)Expand description
Create a bounded batch work queue with the given capacity.
pub fn new_batch_queue(
capacity: usize,
) -> (BatchQueueSender, BatchQueueReceiver)Create a bounded batch work queue with the given capacity.