pub enum FilePurpose {
Assistants,
Batch,
FineTune,
}Expand description
The purpose of a file uploaded to the Files API.
Variants
Assistants
File is used as an attachment for the Assistants API.
Batch
File is used for a Batch API job.
FineTune
File is used for fine-tuning.
Implementations
Sourceimpl FilePurpose
impl FilePurpose
Sourcepub fn from_purpose_str(s: &str) -> Option<Self>
pub fn from_purpose_str(s: &str) -> Option<Self>
Parse a purpose string from a form field value.
Returns None if the string does not match a known purpose.